==> bodo-2022.4-cp39-cp39-win_amd64.whl: bodo/io/np_io.py <==
"""
File to support the numpy file IO API (np.fromfile(), np.tofile()).
The actual definition of fromfile is inside untyped pass with the
other IO operations.
"""
import llvmlite.binding as ll
import numpy as np
from numba.core import types
from numba.extending import intrinsic, overload, overload_method
import bodo
from bodo.libs import hio
from bodo.libs.str_ext import string_type, unicode_to_utf8
from bodo.utils.utils import check_java_installation
ll.add_symbol('get_file_size', hio.get_file_size)
ll.add_symbol('file_read', hio.file_read)
ll.add_symbol('file_read_parallel', hio.file_read_parallel)
ll.add_symbol('file_write', hio.file_write)
ll.add_symbol('file_write_parallel', hio.file_write_parallel)
_get_file_size = types.ExternalFunction('get_file_size', types.int64(types.
    voidptr))
_file_read = types.ExternalFunction('file_read', types.void(types.voidptr,
    types.voidptr, types.intp, types.intp))
_file_read_parallel = types.ExternalFunction('file_read_parallel', types.
    void(types.voidptr, types.voidptr, types.intp, types.intp))
file_write = types.ExternalFunction('file_write', types.void(types.voidptr,
    types.voidptr, types.intp))
_file_write_parallel = types.ExternalFunction('file_write_parallel', types.
    void(types.voidptr, types.voidptr, types.intp, types.intp, types.intp))


@intrinsic
def get_dtype_size(typingctx, dtype=None):
    assert isinstance(dtype, types.DTypeSpec)

    def codegen(context, builder, sig, args):
        pqxxh__lpb = context.get_abi_sizeof(context.get_data_type(dtype.dtype))
        return context.get_constant(types.intp, pqxxh__lpb)
    return types.intp(dtype), codegen


@overload_method(types.Array, 'tofile')
def tofile_overload(arr, fname):
    if fname == string_type or isinstance(fname, types.StringLiteral):

        def tofile_impl(arr, fname):
            check_java_installation(fname)
            qauns__fzo = np.ascontiguousarray(arr)
            dtype_size = get_dtype_size(qauns__fzo.dtype)
            file_write(unicode_to_utf8(fname), qauns__fzo.ctypes, 
                dtype_size * qauns__fzo.size)
            bodo.utils.utils.check_and_propagate_cpp_exception()
        return tofile_impl


def file_write_parallel(fname, arr, start, count):
    pass


@overload(file_write_parallel)
def file_write_parallel_overload(fname, arr, start, count):
    if fname == string_type:

        def _impl(fname, arr, start, count):
            qauns__fzo = np.ascontiguousarray(arr)
            dtype_size = get_dtype_size(qauns__fzo.dtype)
            zvlg__hcxyj = (dtype_size * bodo.libs.distributed_api.
                get_tuple_prod(qauns__fzo.shape[1:]))
            _file_write_parallel(unicode_to_utf8(fname), qauns__fzo.ctypes,
                start, count, zvlg__hcxyj)
            bodo.utils.utils.check_and_propagate_cpp_exception()
        return _impl


def file_read_parallel(fname, arr, start, count):
    return


@overload(file_read_parallel)
def file_read_parallel_overload(fname, arr, start, count, offset):
    if fname == string_type:

        def _impl(fname, arr, start, count, offset):
            dtype_size = get_dtype_size(arr.dtype)
            _file_read_parallel(unicode_to_utf8(fname), arr.ctypes, start *
                dtype_size + offset, count * dtype_size)
            bodo.utils.utils.check_and_propagate_cpp_exception()
        return _impl


def file_read(fname, arr, size, offset):
    return


@overload(file_read)
def file_read_overload(fname, arr, size, offset):
    if fname == string_type:

        def impl(fname, arr, size, offset):
            _file_read(unicode_to_utf8(fname), arr.ctypes, size, offset)
            bodo.utils.utils.check_and_propagate_cpp_exception()
        return impl


def get_file_size(fname, count, offset, dtype_size):
    return 0


@overload(get_file_size)
def get_file_size_overload(fname, count, offset, dtype_size):
    if fname == string_type:

        def impl(fname, count, offset, dtype_size):
            if offset < 0:
                return -1
            isuh__xero = _get_file_size(unicode_to_utf8(fname)) - offset
            bodo.utils.utils.check_and_propagate_cpp_exception()
            if count != -1:
                isuh__xero = min(isuh__xero, count * dtype_size)
            if isuh__xero < 0:
                return -1
            return isuh__xero
        return impl

==> bodo-2022.4.1-cp39-cp39-win_amd64.whl: bodo/io/np_io.py <==
"""
File to support the numpy file IO API (np.fromfile(), np.tofile()).
The actual definition of fromfile is inside untyped pass with the
other IO operations.
"""
import llvmlite.binding as ll
import numpy as np
from numba.core import types
from numba.extending import intrinsic, overload, overload_method
import bodo
from bodo.libs import hio
from bodo.libs.str_ext import string_type, unicode_to_utf8
from bodo.utils.utils import check_java_installation
ll.add_symbol('get_file_size', hio.get_file_size)
ll.add_symbol('file_read', hio.file_read)
ll.add_symbol('file_read_parallel', hio.file_read_parallel)
ll.add_symbol('file_write', hio.file_write)
ll.add_symbol('file_write_parallel', hio.file_write_parallel)
_get_file_size = types.ExternalFunction('get_file_size', types.int64(types.
    voidptr))
_file_read = types.ExternalFunction('file_read', types.void(types.voidptr,
    types.voidptr, types.intp, types.intp))
_file_read_parallel = types.ExternalFunction('file_read_parallel', types.
    void(types.voidptr, types.voidptr, types.intp, types.intp))
file_write = types.ExternalFunction('file_write', types.void(types.voidptr,
    types.voidptr, types.intp))
_file_write_parallel = types.ExternalFunction('file_write_parallel', types.
    void(types.voidptr, types.voidptr, types.intp, types.intp, types.intp))


@intrinsic
def get_dtype_size(typingctx, dtype=None):
    assert isinstance(dtype, types.DTypeSpec)

    def codegen(context, builder, sig, args):
        dcssg__shmp = context.get_abi_sizeof(context.get_data_type(dtype.dtype)
            )
        return context.get_constant(types.intp, dcssg__shmp)
    return types.intp(dtype), codegen


@overload_method(types.Array, 'tofile')
def tofile_overload(arr, fname):
    if fname == string_type or isinstance(fname, types.StringLiteral):

        def tofile_impl(arr, fname):
            check_java_installation(fname)
            pgdr__yidkn = np.ascontiguousarray(arr)
            dtype_size = get_dtype_size(pgdr__yidkn.dtype)
            file_write(unicode_to_utf8(fname), pgdr__yidkn.ctypes, 
                dtype_size * pgdr__yidkn.size)
            bodo.utils.utils.check_and_propagate_cpp_exception()
        return tofile_impl


def file_write_parallel(fname, arr, start, count):
    pass


@overload(file_write_parallel)
def file_write_parallel_overload(fname, arr, start, count):
    if fname == string_type:

        def _impl(fname, arr, start, count):
            pgdr__yidkn = np.ascontiguousarray(arr)
            dtype_size = get_dtype_size(pgdr__yidkn.dtype)
            njgp__feleg = (dtype_size * bodo.libs.distributed_api.
                get_tuple_prod(pgdr__yidkn.shape[1:]))
            _file_write_parallel(unicode_to_utf8(fname), pgdr__yidkn.ctypes,
                start, count, njgp__feleg)
            bodo.utils.utils.check_and_propagate_cpp_exception()
        return _impl


def file_read_parallel(fname, arr, start, count):
    return


@overload(file_read_parallel)
def file_read_parallel_overload(fname, arr, start, count, offset):
    if fname == string_type:

        def _impl(fname, arr, start, count, offset):
            dtype_size = get_dtype_size(arr.dtype)
            _file_read_parallel(unicode_to_utf8(fname), arr.ctypes, start *
                dtype_size + offset, count * dtype_size)
            bodo.utils.utils.check_and_propagate_cpp_exception()
        return _impl


def file_read(fname, arr, size, offset):
    return


@overload(file_read)
def file_read_overload(fname, arr, size, offset):
    if fname == string_type:

        def impl(fname, arr, size, offset):
            _file_read(unicode_to_utf8(fname), arr.ctypes, size, offset)
            bodo.utils.utils.check_and_propagate_cpp_exception()
        return impl


def get_file_size(fname, count, offset, dtype_size):
    return 0


@overload(get_file_size)
def get_file_size_overload(fname, count, offset, dtype_size):
    if fname == string_type:

        def impl(fname, count, offset, dtype_size):
            if offset < 0:
                return -1
            xblz__fml = _get_file_size(unicode_to_utf8(fname)) - offset
            bodo.utils.utils.check_and_propagate_cpp_exception()
            if count != -1:
                xblz__fml = min(xblz__fml, count * dtype_size)
            if xblz__fml < 0:
                return -1
            return xblz__fml
        return impl
